==> hs-glade-0.12.1_3.tbz: lib/ghc-7.4.1/cabal/glade-0.12.1/register.sh <==
#!/bin/sh
echo 'name: glade
version: 0.12.1
id: glade-0.12.1-1fb4a53422bc485eebbff921657915d5

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@sourceforge.net
stability: provisional
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the glade library.
description: This library allows to load externally stored user interfaces into
             programs. This allows alteration of the interface without recompilation
             of the program.
             .
             Note that this functionality is now provided in gtk directly
             (as of version 2.12 of the gtk+ C lib) by the
             Graphics.UI.Gtk.Builder module.
category: Graphics
author: Manuel M T Chakravarty, Duncan Coutts
exposed: True
exposed-modules: Graphics.UI.Gtk.Glade
hidden-modules: Graphics.UI.Gtk.Glade.Types
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/glade-0.12.1
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/glade-0.12.1
              /usr/local/lib
hs-libraries: HSglade-0.12.1
extra-libraries: glade-2.0 gtk-x11-2.0 gdk-x11-2.0 pangocairo-1.0
                 Xext Xrender Xinerama Xi Xrandr Xcursor Xcomposite Xdamage Xfixes
                 X11 atk-1.0 cairo gdk_pixbuf-2.0 gio-2.0 pangoft2-1.0 pango-1.0 m
                 gobject-2.0 gthread-2.0 gmodule-2.0 glib-2.0 freetype fontconfig
                 xml2
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/libglade-2.0
              /usr/local/include/gtk-2.0 /usr/local/include/gio-unix-2.0/
              /usr/local/include/atk-1.0 /usr/local/include/cairo
              /usr/local/include/pixman-1 /usr/local/include/gdk-pixbuf-2.0
              /usr/local/include/libpng15 /usr/local/include/pango-1.0
              /usr/local/include/glib-2.0 /usr/local/include/freetype2
              /usr/local/include/libxml2
includes:
depends: base-4.5.0.0-3459bca6d8e46666b517e8bb2e033728
         glib-0.12.3.1-b8fe1b8554ac9f9afc9af7e353ede55d
         gtk-0.12.3.1-8944cfaf379e3b30413e44996c4732fe
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/glade-0.12.1/html/glade.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/glade-0.12.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-glade-0.12.1_5.tbz: lib/ghc-7.4.2/cabal/glade-0.12.1/register.sh <==
#!/bin/sh
echo 'name: glade
version: 0.12.1
id: glade-0.12.1-244e9d748f7f4c896b5bc065fa8115ad

license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@sourceforge.net
stability: provisional
homepage: http://projects.haskell.org/gtk2hs/
package-url:
synopsis: Binding to the glade library.
description: This library allows to load externally stored user interfaces into
             programs. This allows alteration of the interface without recompilation
             of the program.
             .
             Note that this functionality is now provided in gtk directly
             (as of version 2.12 of the gtk+ C lib) by the
             Graphics.UI.Gtk.Builder module.
category: Graphics
author: Manuel M T Chakravarty, Duncan Coutts
exposed: True
exposed-modules: Graphics.UI.Gtk.Glade
hidden-modules: Graphics.UI.Gtk.Glade.Types
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/glade-0.12.1
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/glade-0.12.1
              /usr/local/lib
hs-libraries: HSglade-0.12.1
extra-libraries: glade-2.0 gtk-x11-2.0 gdk-x11-2.0 pangocairo-1.0
                 Xext Xrender Xinerama Xi Xrandr Xcursor Xcomposite Xdamage Xfixes
                 X11 atk-1.0 cairo gdk_pixbuf-2.0 gio-2.0 pangoft2-1.0 pango-1.0
                 gobject-2.0 glib-2.0 freetype fontconfig xml2
extra-ghci-libraries:
include-dirs: /usr/local/include /usr/local/include/libglade-2.0
              /usr/local/include/gtk-2.0 /usr/local/include/gio-unix-2.0/
              /usr/local/include/atk-1.0 /usr/local/include/cairo
              /usr/local/include/pixman-1 /usr/local/include/gdk-pixbuf-2.0
              /usr/local/include/libpng15 /usr/local/include/pango-1.0
              /usr/local/include/glib-2.0 /usr/local/include/freetype2
              /usr/local/include/libxml2
includes:
depends: base-4.5.1.0-12fddc14a7babb909dd3843e453b5660
         glib-0.12.4-dc7ab9255cefef81913c196fd3b53d89
         gtk-0.12.4-1951292e52dab9a09dcaa043d8e9593e
hugs-options:
cc-options:
ld-options: -pthread
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/glade-0.12.1/html/glade.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/glade-0.12.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
